@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: tlmgrgui.pl 50334 2019-03-11 01:56:18Z preining $
+# $Id: tlmgrgui.pl 58343 2021-03-14 02:46:32Z preining $
 #
 # Copyright 2009-2019 Norbert Preining
 # This file is licensed under the GNU General Public License version 2
@@ -13,8 +13,8 @@
 $^W = 1;
 use strict;
 
-my $guisvnrev = '$Revision: 50334 $';
-my $guidatrev = '$Date: 2019-03-11 02:56:18 +0100 (Mon, 11 Mar 2019) $';
+my $guisvnrev = '$Revision: 58343 $';
+my $guidatrev = '$Date: 2021-03-14 03:46:32 +0100 (Sun, 14 Mar 2021) $';
 my $tlmgrguirevision;
 if ($guisvnrev =~ m/: ([0-9]+) /) {
   $tlmgrguirevision = $1;
@@ -126,13 +126,7 @@ my $match_filenames = 1;
 my $match_text = "";
 my $selection_value = 0;
 
-
-# prepare for loading of lang.pl which expects $::lang and $::opt_lang
-$::opt_lang = $config{"gui-lang"} if (defined($config{"gui-lang"}));
-$::opt_lang = $opts{"gui-lang"} if (defined($opts{"gui-lang"}));
-require("TeXLive/trans.pl");
-load_translations();
-
+# locale support moved to tlmgr.pl
 
 my @archsavail;
 my @archsinstalled;
@@ -556,7 +550,7 @@ sub setup_menu_system {
       -command => sub { do_arch_settings(); });
   }
   if ($mode_expert) {
-    $menu_options->add('command', -label => __("GUI Language ..."),
+    $menu_options->add('command', -label => __("GUI language ..."),
       -command => sub { do_gui_language_setting(); });
   }
   $menu_options->add('separator');
@@ -631,7 +625,7 @@ sub setup_menu_system {
                                 -command => sub { 
                                   my $b = shift;
                                   if ($b eq __("Ok")) {
-                                    system("tlmgr", "uninstall", "--force");
+                                    system("tlmgr", "remove", "--all", "--force");
                                     $mw->Dialog(-text => __("Complete removal finished"), -buttons => [ __("Ok") ])->Show;
                                     $mw->destroy; 
                                     exit(0); 
@@ -1353,9 +1347,9 @@ sub do_paper_settings {
 
 
   my $back_config_pap_l1 = $back_config_pap->Label(-text => __("Default paper for all"), -anchor => "w");
-  my $back_config_pap_m1 = $back_config_pap->Button(-text => __("a4"),
+  my $back_config_pap_m1 = $back_config_pap->Button(-text => __("A4"),
     -command => sub { change_paper("all", "a4"); });
-  my $back_config_pap_r1 = $back_config_pap->Button(-text => __("letter"),
+  my $back_config_pap_r1 = $back_config_pap->Button(-text => __("Letter"),
     -command => sub { change_paper("all", "letter"); });
 
   $back_config_pap_l1->grid( $back_config_pap_m1, $back_config_pap_r1,
