@@ -74,11 +74,13 @@ if not modules then modules = { } end modules ['lang-hyp'] = {
 -- ins       : when hyphenationbounds 2 or 3
 -- adjust    : when hyphenationbounds 2 or 3
 
-local type, rawset, tonumber, next = type, rawset, tonumber, next
+local type, rawget, rawset, tonumber, next = type, rawget, rawset, tonumber, next
 
 local P, R, S, Cg, Cf, Ct, Cc, C, Carg, Cs = lpeg.P, lpeg.R, lpeg.S, lpeg.Cg, lpeg.Cf, lpeg.Ct, lpeg.Cc, lpeg.C, lpeg.Carg, lpeg.Cs
 local lpegmatch = lpeg.match
 
+local context    = context
+
 local concat     = table.concat
 local insert     = table.insert
 local remove     = table.remove
@@ -624,13 +626,10 @@ if context then
     local math_code          = nodecodes.math
     local hlist_code         = nodecodes.hlist
 
-    local discretionary_code = disccodes.discretionary
-    local explicit_code      = disccodes.explicit
-    local automatic_code     = disccodes.automatic
-    local regular_code       = disccodes.regular
+    local automaticdisc_code = disccodes.automatic
+    local regulardisc_code   = disccodes.regular
 
     local nuts               = nodes.nuts
-    local tonut              = nodes.tonut
     local tonode             = nodes.tonode
     local nodepool           = nuts.pool
 
@@ -645,7 +644,7 @@ if context then
     local getprev            = nuts.getprev
     local getsubtype         = nuts.getsubtype
     local getlist            = nuts.getlist
-    local getlang            = nuts.getlang
+    local getlanguage        = nuts.getlanguage
     local getattrlist        = nuts.getattrlist
     local setattrlist        = nuts.setattrlist
     local isglyph            = nuts.isglyph
@@ -664,7 +663,9 @@ if context then
     local remove_node        = nuts.remove
     local end_of_math        = nuts.end_of_math
     local node_tail          = nuts.tail
-    local traverse_id        = nuts.traverse_id
+
+    local nexthlist          = nuts.traversers.hlist
+    local nextdisc           = nuts.traversers.disc
 
     local setcolor           = nodes.tracers.colors.set
 
@@ -686,10 +687,6 @@ if context then
 
     local a_hyphenation      = attributes.private("hyphenation")
 
-    local expanders          = languages.expanders -- gone in 1.005
-    local expand_explicit    = expanders and expanders[explicit_code]
-    local expand_automatic   = expanders and expanders[automatic_code]
-
     local interwordpenalty   = 5000
 
     function traditional.loadpatterns(language)
@@ -982,7 +979,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
     implement {
         name      = "registerhyphenationexception",
         actions   = traditional.registerexception,
-        arguments = { "string",  "string" }
+        arguments = "2 strings",
     }
 
     -- This is a relative large function with local variables and local functions. A previous
@@ -1030,9 +1027,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
 
     function traditional.hyphenate(head)
 
-        local first           = tonut(head)
-
-
+        local first           = head
         local tail            = nil
         local last            = nil
         local current         = first
@@ -1044,6 +1039,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
         local extrachars      = nil
         local hyphenchars     = nil
         local language        = nil
+        local lastfont        = nil
         local start           = nil
         local stop            = nil
         local word            = { } -- we reuse this table
@@ -1290,7 +1286,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
                     if leftchar then
                         post = serialize(true,leftchar)
                     end
-                    setdisc(disc,pre,post,nil,regular_code,hyphenpenalty)
+                    setdisc(disc,pre,post,nil,regulardisc_code,hyphenpenalty)
                     if attrnode then
                         setattrlist(disc,attrnode)
                     end
@@ -1325,7 +1321,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
                         end
                     end
                     -- maybe regular code
-                    setdisc(disc,pre,post,replace,regular_code,hyphenpenalty)
+                    setdisc(disc,pre,post,replace,regulardisc_code,hyphenpenalty)
                     if attrnode then
                         setattrlist(disc,attrnode)
                     end
@@ -1365,7 +1361,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
                 end
                 pre = copy_node(glyph)
                 setchar(pre,rightchar and rightchar > 0 and rightchar or code)
-                setdisc(disc,pre,post,replace,automatic_code,hyphenpenalty) -- ex ?
+                setdisc(disc,pre,post,replace,automaticdisc_code,hyphenpenalty) -- ex ?
                 if attrnode then
                     setattrlist(disc,attrnode)
                 end
@@ -1387,7 +1383,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
             local pre     = copy_list(start)
             local post    = nil
             local replace = start
-            setdisc(disc,pre,post,replace,automatic_code,hyphenpenalty) -- ex ?
+            setdisc(disc,pre,post,replace,automaticdisc_code,hyphenpenalty) -- ex ?
             if attrnode then
                 setattrlist(disc,attrnode)
             end
@@ -1406,14 +1402,17 @@ featureset.hyphenonly   = hyphenonly == v_yes
 
         local skipping = false
 
+        -- In "word word word." the sequences "word" and "." can be a different font!
+
         while current and current ~= last do -- and current
             local code, id = isglyph(current)
             if code then
                 if skipping then
                     current = getnext(current)
                 else
-                    local lang = getlang(current)
-                    if lang ~= language then
+                    local lang = getlanguage(current)
+                    local font = getfont(current)
+                    if lang ~= language or font ~= lastfont then
                         if dictionary and size > charmin and leftmin + rightmin <= size then
                             -- only german has many words starting with an uppercase character
                             if categories[word[1]] == "lu" and getfield(start,"uchyph") < 0 then
@@ -1425,10 +1424,10 @@ featureset.hyphenonly   = hyphenonly == v_yes
                                 end
                             end
                         end
-                        language = lang
-                        if language > 0 then
+                        lastfont = font
+                        if language ~= lang and lang > 0 then
                             --
-                            dictionary = dictionaries[language]
+                            dictionary = dictionaries[lang]
                             instance   = dictionary.instance
                             characters = dictionary.characters
                             unicodes   = dictionary.unicodes
@@ -1459,6 +1458,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
                         else
                             size = 0
                         end
+                        language = lang
                     elseif language <= 0 then
                         --
                     elseif size > 0 then
@@ -1541,28 +1541,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
                     skipping = false
                 end
                 if id == disc_code then
-                    if expanded then
-                        -- pre 1.005
-                        local subtype = getsubtype(current)
-                        if subtype == discretionary_code then -- \discretionary
-                            size = 0
-                        elseif subtype == explicit_code then -- \- => only here
-                            -- automatic (-) : the old parser makes negative char entries
-                            size = 0
-                            expand_explicit(current)
-                        elseif subtype == automatic_code then -- - => only here
-                            -- automatic (-) : the old hyphenator turns an exhyphen into glyph+disc
-                            size = 0
-                            expand_automatic(current)
-                        else
-                            -- first         : done by the hyphenator
-                            -- second        : done by the hyphenator
-                            -- regular       : done by the hyphenator
-                            size = 0
-                        end
-                    else
-                        size = 0
-                    end
+                    size = 0
                     current = getnext(current)
                     if hyphenonly then
                         skipping = true
@@ -1603,7 +1582,7 @@ featureset.hyphenonly   = hyphenonly == v_yes
 
         stoptiming(traditional)
 
-        return head, true
+        return head
     end
 
     statistics.register("hyphenation",function()
@@ -1631,39 +1610,31 @@ featureset.hyphenonly   = hyphenonly == v_yes
 
     -- local replaceaction = nodes.tasks.replaceaction -- no longer overload this way (too many local switches)
 
-    local hyphenate  = lang.hyphenate
-    local expanders  = languages.expanders
-    local methods    = { }
-    local usedmethod = false
-    local stack      = { }
+    local hyphenate    = lang.hyphenate
+    local hyphenating  = nuts.hyphenating
+    local methods      = { }
+    local usedmethod   = false
+    local stack        = { }
 
-    local function original(head)
-        local done = hyphenate(head)
-        return head, done
-    end
-
-    local expanded = function (head)
-        local done = hyphenate(head)
-        return head, done
-    end
-
-    if LUATEXVERSION< 1.005 then
-
-        expanded = function(head)
-            local done = hyphenate(head)
-            if done then
-                for d in traverse_id(disc_code,tonut(head)) do
-                    local s = getsubtype(d)
-                    if s ~= discretionary_code then
-                        expanders[s](d,template)
-                        done = true
-                    end
-                end
-            end
-            return head, done
+    local original = hyphenating and
+        function(head)
+            return (hyphenating(head))
+        end
+    or
+        function(head)
+            hyphenate(tonode(head))
+            return head -- a nut
         end
 
-    end
+ -- local has_language = lang.has_language
+ --
+ -- local function original(head) -- kernel.hyphenation(head)
+ --     local h = tonode(head)
+ --     if has_language(h) then
+ --         hyphenate(h)
+ --     end
+ --     return head
+ -- end
 
     local getcount = tex.getcount
 
@@ -1679,19 +1650,19 @@ featureset.hyphenonly   = hyphenonly == v_yes
                     forced = false
                     return usedmethod(head)
                 else
-                    return head, false
+                    return head
                 end
             else
                 return usedmethod(head)
             end
         else
-            return head, false
+            return head
         end
     end
 
     methods.tex         = original
     methods.original    = original
-    methods.expanded    = expanded -- obsolete starting with 1.005
+    methods.expanded    = original -- was expanded before 1.005
     methods.traditional = languages.hyphenators.traditional.hyphenate
     methods.none        = false -- function(head) return head, false end
 
@@ -1767,17 +1738,16 @@ featureset.hyphenonly   = hyphenonly == v_yes
     implement {
         name      = "showhyphenationtrace",
         actions   = hyphenators.showhyphenationtrace,
-        arguments = { "string", "string" }
+        arguments = "2 strings",
     }
 
     function nodes.stripdiscretionaries(head)
-        local h = tonut(head)
-        for l in traverse_id(hlist_code,h) do
-            for d in traverse_id(disc_code,getlist(l)) do
+        for l in nexthlist, head do
+            for d in nextdisc, getlist(l) do
                 remove_node(h,false,true)
             end
         end
-        return tonode(h)
+        return head
     end
 
 
