@@ -4,9 +4,11 @@
 -- REQUIREMENTS:  
 --       AUTHOR:  Herbert Voß
 --      LICENSE:  LPPL1.3
+--
+-- $Id: xindex-base.lua 22 2022-02-07 12:18:15Z hvoss $
 -----------------------------------------------------------------------
 
-local info = { version = 0.23 } 
+local info = { version = 0.41 } 
 
 -- check config
 if pageNoPrefixDel ~= "" then 
@@ -14,9 +16,36 @@ if pageNoPrefixDel ~= "" then
    pageNoPrefixPattern = "^.*"..pageNoPrefixDel
 end
 
-writeLog(2,"Read Data from file "..inFile.." ... \n",0)
-local lines = read_lines_from(inFile)
-writeLog(2,#lines.." lines of data read\n",0)
+local lines = {}
+
+if useStdInput then
+  writeLog(2,"Read Data from stdin ... \n",0)
+  for line in io.lines() do
+    lines[#lines+1] = line
+  end
+  writeLog(2,#lines.." lines of data read\n",0)
+else
+  for i=1,#inFiles do
+    writeLog(2,"Read Data from file "..inFiles[i].." ... \n",0)
+    lines = array_concat(lines, read_lines_from(inFiles[i]))
+    writeLog(2,#lines.." lines of data read\n",0)
+  end
+end
+print("Anzahl Zeilen: "..#lines)
+if #lines == 0 then
+    print("=========================================")
+    print("Input file(s) is/are empty!")
+    print("Leaving program xindex")
+    print("=========================================")
+    outFile:write("\n")
+    outFile:write(envStart.."\n")
+    if indexOpening ~= "" then   -- commands after \begin{theindex}
+      outFile:write(indexOpening) 
+    end
+    outFile:write(envStop.."\n")
+    outFile:close()
+    os.exit()
+end
 
 if vlevel > 1 then 
   writeLog(1,"--------------- Input data -----------------\n",2)
@@ -35,10 +64,12 @@ if hyperpage then writeLog(1,"We have hyperpages ... \n",1) end
 --for _,l in pairs(lines) do print (l) end
 
 writeLog(1,"Change escape chars with macros ... \n",0)
-for k,v in pairs(lines) do
+for k,v in ipairs(lines) do  
   if not commandEntry(v) then
-    for i, str0 in ipairs(escape_chars) do
-      v = v:gsub(str0[1],str0[2])
+    for i, str0 in ipairs(escape_chars) do  -- str0: esc-char, coded, char
+--      print(str0[1],str0[2],v)
+      v = string.gsub(v,str0[1],str0[2])
+--      print("==> "..v)
     end
     if k < #lines then
       if commandEntry(lines[k+1]) then   -- is the next line not a \indexentry ?
@@ -102,13 +133,13 @@ writeLog(2,"done\n",0)
 
 writeLog(2,"Replace @-operator ...\n",0)
 writeLog(1,"------------------ Start list before compressEntryList(Index)------------\n",1)
-writeLog(1,require 'xindex-pretty'.dump(Index),3)   -- only for internal dump
+--writeLog(1,require 'xindex-pretty'.dump(Index),3)   -- only for internal dump
 
 local NewIndex = {}
 NewIndex = compressEntryList(Index)   -- replaces also foo@bar -> bar
 
 -- for i=1,#NewIndex do print(NewIndex[i]["Entry"],NewIndex[i]["pages"][1]["number"],NewIndex[i]["pages"][1]["special"]) end
-writeLog(1,require 'xindex-pretty'.dump(NewIndex),3)   -- only for internal dump
+--writeLog(1,require 'xindex-pretty'.dump(NewIndex),3)   -- only for internal dump
 printList(NewIndex,2)
 writeLog(1,"------------------ End list after compressEntryList(Index)------------\n",1)
 writeLog(2,"done\n",0)
@@ -121,6 +152,7 @@ end
 ]]   -- no more needed, we redo the setting 
 
 if use_UCA then
+  writeLog(2,"Endhook for UCA ...",0)
   for i=1, #NewIndex do
     v = NewIndex[i]
     -- the collator:get_lowest_char will return character on the given
@@ -133,6 +165,7 @@ if use_UCA then
       v.sortChar = getSortChar(codepoints)
     end
   end
+  writeLog(2,"done\n",0)
 end
 
 if SORTendhook then
@@ -140,7 +173,7 @@ if SORTendhook then
 end
 
 outFile:write("\n")
-outFile:write("\\begin{theindex}\n")
+outFile:write(envStart.."\n")
 
 if indexOpening ~= "" then   -- commands after \begin{theindex}
   outFile:write(indexOpening) 
@@ -162,6 +195,7 @@ local excl = 0 --  number of ! symbols in one entry
 local lastItems = {"","",""}
 indLines = 0
 writeLog(2,"Start writing .ind file ... \n",0)
+require 'xindex-pretty'.dump(NewIndex)   -- only for internal dump
 
 -- first the special cases for symbols and numbers:
 
@@ -204,11 +238,17 @@ for k=1,#NewIndex do
       if firstSLine then
         firstSLine = false
         if not no_headings then
-          outFile:write("\\par"..idxnewletter.."{"..index_header[1].."}")
-          if (labelPrefix == "") then
-            outFile:write("\\label{xindex-"..index_header[1].."}\n\\nopagebreak[4]\n")
+          outFile:write(idxnewletter.."{"..index_header[1].."}")
+          indLines = indLines + 1
+--          outFile:write("\\par"..idxnewletter.."{"..index_header[1].."}")
+          if no_labels then
+            outFile:write("\n\\nopagebreak[4]\n")
           else
-            outFile:write("\\label{"..labelPrefix.."-xindex-"..index_header[1].."}\n\\nopagebreak[4]\n")
+            if (labelPrefix == "") then
+              outFile:write("\\label{xindex-symbols}\n\\nopagebreak[4]\n")
+            else
+              outFile:write("\\label{"..labelPrefix.."-xindex-symbols}\n\\nopagebreak[4]\n")
+            end
           end
         end
       end
@@ -225,12 +265,20 @@ for k=1,#NewIndex do
       if firstNLine then
         firstNLine = false
         outFile:write("\n\\indexspace\n")
+        indLines = indLines + 1
         if not no_headings  then
           outFile:write(idxnewletter.."{"..index_header[2].."}")
-          if (labelPrefix == "") then
-            outFile:write("\\label{xindex-"..index_header[2].."}\n\\nopagebreak[4]\n")
+          indLines = indLines + 1
+          if no_labels then
+            outFile:write("\n\\nopagebreak[4]\n")
+            indLines = indLines + 1
           else
-            outFile:write("\\label{"..labelPrefix.."-xindex-"..index_header[2].."}\n\\nopagebreak[4]\n")
+            if (labelPrefix == "") then
+              outFile:write("\\label{xindex-numbers}\n\\nopagebreak[4]\n")
+            else
+              outFile:write("\\label{"..labelPrefix.."-xindex-numbers}\n\\nopagebreak[4]\n")
+            end
+            indLines = indLines + 1
           end
         end
       end
@@ -246,14 +294,21 @@ for k=1,#NewIndex do
       writeLog(1,"We have letters to print ...\n",3) 
       if (currentChar ~= oldChar) and (charType == 2) then 
         outFile:write("\n\\indexspace\n")
+        indLines = indLines + 1
         if not no_headings then
           outFile:write(idxnewletter.."{"..currentChar.."}")
-          if (labelPrefix == '""') then
-            outFile:write("\\label{xindex-"..currentChar.."}\n\\nopagebreak[4]\n")
+          indLines = indLines + 1
+          if no_labels then
+            outFile:write("\n\\nopagebreak[4]\n")
           else
-            outFile:write("\\label{"..labelPrefix.."-xindex-"..currentChar.."}\n\\nopagebreak[4]\n")
+            if (labelPrefix == '""') then
+              outFile:write("\\label{xindex-"..currentChar.."}\n\\nopagebreak[4]\n")
+            else
+              outFile:write("\\label{"..labelPrefix.."-xindex-"..currentChar.."}\n\\nopagebreak[4]\n")
+            end
+            indLines = indLines + 1
           end
-        end
+        end  -- not no_headings
         oldChar = currentChar
       end
       if specialItemOutput then
@@ -265,8 +320,8 @@ for k=1,#NewIndex do
     if v["Macro"]  then outFile:write(v["Macro"].."\n") end
   end
 end
-outFile:write("\\end{theindex}\n")
-writeLog(2,indLines.." lines of data wrote into the .ind file\n",0)
+outFile:write(envStop.."\n")
+writeLog(2,indLines.." lines of data wrote into the "..outfilename.." file\n",0)
 outFile:close()
 
 writeLog(2,"\ndone! closing program\n",0)
