@@ -1,15 +1,15 @@
 #!/usr/bin/env perl
-# $Id: install-menu-text.pl 50297 2019-03-08 23:16:36Z karl $
-# install-menu-txt.pl
+# $Id: install-menu-text.pl 62571 2022-03-09 22:53:42Z karl $
 #
-# Copyright 2007-2017 Norbert Preining, Karl Berry
+# Copyright 2007-2022 Norbert Preining, Karl Berry
 # Copyright 2007-2008 Reinhard Kotucha
 # This file is licensed under the GNU General Public License version 2
 # or any later version.
 #
 # This file implements the text based menu system for the TeX Live installer.
 
-use vars qw(@::end_install_hook $::opt_no_cls);
+use vars qw(@::end_install_hook
+            $::opt_no_cls $::opt_select_repository $::run_menu);
 
 our %vars;
 our $opt_in_place;
@@ -33,14 +33,14 @@ my $ptoggle_alert = "\n".
     "   !! Portable option changed;\n" .
     "   !! Directories have been reinitialized!\n";
 
-# @fileassocdesc also defined in install-tl
-$::fileassocdesc[0] = "None";
-$::fileassocdesc[1] = "Only new";
-$::fileassocdesc[2] = "All";
+# some strings to describe the different meanings of tlpdbopt_file_assoc
+$::fileassocdesc[0] = __("None");
+$::fileassocdesc[1] = __("Only new");
+$::fileassocdesc[2] = __("All");
 
-$::deskintdesc[0] = "None";
-$::deskintdesc[1] = "Menu shortcuts";
-if (win32() && is_seven()) { $::deskintdesc[2] = "Launcher"; }
+$::deskintdesc[0] = __("None");
+$::deskintdesc[1] = __("Menu shortcuts");
+if (win32()) { $::deskintdesc[2] = __("Launcher"); }
 
 sub clear_screen {
   return 0 if ($::opt_no_cls);
@@ -52,9 +52,6 @@ sub string_to_list {
   return split(//, $string);
 }
 
-# ___, defined in install-tl, replaces the GUI translating function
-*::__ = \&::___;
-
 sub button { # for main menu: 1 char
   my $val=shift;
   my $vals=shift; # array ref to descriptions of possible values
@@ -96,7 +93,6 @@ sub other_options {
   my %opts=(
     '-' => 'deselect all',
     '+' => 'select all',
-    'H' => 'help',
     'R' => 'return to main menu',
     'P' => 'save installation profile to \'texlive.profile\' and exit',
     'Q' => 'quit'
@@ -243,7 +239,7 @@ sub run_menu_text {
     warn "\n";
     warn "Please select a different mirror!  See info above.\n";
     print STDERR "Press Enter to exit... ";
-    $ans = readline (*STDIN);
+    my $ans = readline (*STDIN);
     exit (1);
   }
 
@@ -253,14 +249,14 @@ sub run_menu_text {
     my $f = shift @args;
     if ($f =~ m/^-old-installation-found=(.*)$/) {
       my $dn = $1;
-      print "\nAn old installation of TeX Live has been found in $dn\n";
+      print "\nAn existing installation of TeX Live has been found in $dn\n";
       print "
-If you want the selection of schemes/collections and various options being
-taken over press `y', otherwise anything else.
+If you want its selection of schemes/collections and various options
+to be used, press `y', otherwise anything else.
 
 Import settings from previous TeX Live installation: (y/n): ";
       chomp(my $yn = <STDIN>);
-      if ($yn =~ m/^y$/i) {
+      if (defined $yn && $yn =~ m/^y$/i) {
         import_settings_from_old_tlpdb($dn);
       }
     }
@@ -503,7 +499,7 @@ sub directories_menu
       );
 
   menu_head "Directories customization:";
-  if (!TeXLive::TLUtils::texdir_check($vars{'TEXDIR'})) {
+  if (!TeXLive::TLUtils::texdir_check($vars{'TEXDIR'}, 1)) {
     print "!! The default location as given below is forbidden or
 !! can't be written to.
 !! Either change the destination directory using <1> or create it
@@ -549,6 +545,10 @@ EOF
   if ("\u$answer" eq '1' and !$opt_in_place) {
     print "New value for TEXDIR [$vars{'TEXDIR'}]: ";
     $answer = &input_dirname ();
+    # update free space information
+    if ($answer ne $vars{'TEXDIR'}) {
+      $vars{'free_size'} = TeXLive::TLUtils::diskfree($answer);
+    }
     $vars{'TEXDIR'} = $answer if $answer ne "";
     my $texdirnoslash;
     if ($vars{'TEXDIR'}=~/^(.*)\/$texlive_release$/) {
@@ -710,13 +710,16 @@ sub html2text {
 }
 
 
+# dumping the html doc to stdout does not seem very helpful,
+# and did not work for years with no one noticing, so this
+# function is no longer used.
 sub help_menu {
   my %command=(
     'self' => \&help_menu,
     'R' => \&main_menu,
     'Q' => \&quit
       );
-  my $installer_help="$installerdir/tlpkg/installer/install-tl.html";
+  my $installer_help = "notused/tlpkg/installer/install-tl.html";
 
   clear_screen;
 
@@ -959,7 +962,36 @@ sub quit {
 }
 
 sub do_install {
-  $RETURN = $MENU_INSTALL;
+  my $reserve = 100;
+  my $doit = 1;
+  if ($vars{'free_size'} > 0
+      && $vars{'free_size'} + $reserve < $vars{'total_size'}) { 
+    print STDERR <<"EOF";
+*** WARNING ****************************************************
+The installation requires $vars{'total_size'}M of disk space
+but only $vars{'free_size'}M is available.
+
+You probably want to either clean up the destination filesystem,
+or choose a different installation location,
+or reduce what gets installed.
+
+Press Enter to return to the menu, or i to install anyway.
+****************************************************************
+EOF
+    my $ans = readline (*STDIN);
+    $doit = 0;
+    chomp($ans);
+    if ($ans eq "i" or $ans eq "I") {
+      $doit = 1;
+    }
+  }
+  if ($doit) {
+    # set env variable to make install-tl not trip over
+    $ENV{'TEXLIVE_INSTALL_NO_DISKCHECK'} = 1;
+    $RETURN = $MENU_INSTALL;
+  } else {
+    main_menu();
+  }
 }
 
 sub toggle_portable {
@@ -1023,7 +1055,6 @@ sub main_menu {
   my %command = (
     'self' => \&main_menu,
     'D' => \&directories_menu,
-    'H' => \&help_menu,
     'I' => \&do_install,
     'O' => \&options_menu,
     'Q' => \&quit,
@@ -1037,11 +1068,13 @@ sub main_menu {
   }
 
   clear_screen;
+  my $freestring = ($vars{'free_size'} >= 0 ? " (free: $vars{'free_size'} MB)" : "");
   print <<"EOF";
 ======================> TeX Live installation procedure <=====================
 
 ======>   Letters/digits in <angle brackets> indicate   <=======
 ======>   menu items for actions or customizations      <=======
+= help>   https://tug.org/texlive/doc/install-tl.html   <=======
 
  Detected platform: $this_platform
  $warn_nobin
@@ -1054,7 +1087,7 @@ EOF
  <S> set installation scheme: $vars{'selected_scheme'}
 
  <C> set installation collections:
-     $vars{'n_collections_selected'} collections out of $vars{'n_collections_available'}, disk space required: $vars{'total_size'} MB
+     $vars{'n_collections_selected'} collections out of $vars{'n_collections_available'}, disk space required: $vars{'total_size'} MB$freestring
 EOF
 
   }
@@ -1068,7 +1101,7 @@ EOF
    TEXDIR (the main TeX directory):
 EOF
 
-  if (TeXLive::TLUtils::texdir_check($vars{'TEXDIR'})) {
+  if (TeXLive::TLUtils::texdir_check($vars{'TEXDIR'}, 1)) {
     print "     $vars{'TEXDIR'}\n";
   } else {
     print "     !! default location: $vars{'TEXDIR'}\n";
@@ -1130,7 +1163,7 @@ EOF
     print "\n <V> set up for portable installation\n";
   }
 
-  other_options qw(I P H Q);
+  other_options qw(I P Q);
   my $answer = prompt 'Enter command';
 
   if (defined $command{"\u$answer"}) {
